@@ -176,36 +176,38 @@ class EventMessage:
         return RelationUpdate(self._raw_data[RELATION_UPDATE])
 
 
-class EventCallback(ABC):
+class AsyncEventCallback(ABC):
     """For implementers to get notified about EventMessages."""
 
     @abstractmethod
-    def handle_event(self, event_message: EventMessage):
+    async def async_handle_event(self, event_message: EventMessage):
         """Process an incoming EventMessage."""
 
 
-class EventTypeFilterCallback(EventCallback):
+class EventTypeFilterCallback(AsyncEventCallback):
     """Invokes a delegate only for events that match the trait type."""
 
-    def __init__(self, event_name, delegate: EventCallback):
+    def __init__(self, event_name, delegate: AsyncEventCallback):
         self._event_name = event_name
         self._delegate = delegate
 
-    def handle_event(self, event_message: EventMessage):
+    async def async_handle_event(self, event_message: EventMessage):
         """Process an incoming EventMessage."""
         events = event_message.resource_update_events
         if self._event_name in events:
-            self._delegate.handle_event(event_message)
+            await self._delegate.async_handle_event(event_message)
 
 
-class RecentEventFilterCallback(EventCallback):
+class RecentEventFilterCallback(AsyncEventCallback):
     """Invokes a delegate only for recent events."""
 
-    def __init__(self, cutoff_timedelta: datetime.timedelta, delegate: EventCallback):
+    def __init__(
+        self, cutoff_timedelta: datetime.timedelta, delegate: AsyncEventCallback
+    ):
         self._cutoff_timedelta = cutoff_timedelta
         self._delegate = delegate
 
-    def handle_event(self, event_message: EventMessage):
+    async def async_handle_event(self, event_message: EventMessage):
         """Process an incoming EventMessage."""
         if not event_message.timestamp:
             return
@@ -216,4 +218,4 @@ class RecentEventFilterCallback(EventCallback):
                 "Ignoring event that is too old (%s)", event_message.timestamp
             )
             return
-        self._delegate.handle_event(event_message)
+        await self._delegate.async_handle_event(event_message)
